# TabStop

A tab stop within a paragraph.

**Type:** object

## Properties

- **offset** ([Dimension](dimension.md)): The offset between this tab stop and the start margin.
- **alignment** (enum): The alignment of this tab stop. If unset, the value defaults to START.
